@@ -173,36 +173,6 @@ Related Options:
 ]
 
 common_opts = [
-    cfg.BoolOpt('allow_additional_image_properties', default=True,
-                deprecated_for_removal=True,
-                deprecated_since="Ussuri",
-                deprecated_reason=_("""
-This option is redundant.  Control custom image property usage via the
-'image_property_quota' configuration option.  This option is scheduled
-to be removed during the Victoria development cycle.
-"""),
-                help=_("""
-Allow users to add additional/custom properties to images.
-
-Glance defines a standard set of properties (in its schema) that
-appear on every image. These properties are also known as
-``base properties``. In addition to these properties, Glance
-allows users to add custom properties to images. These are known
-as ``additional properties``.
-
-By default, this configuration option is set to ``True`` and users
-are allowed to add additional properties. The number of additional
-properties that can be added to an image can be controlled via
-``image_property_quota`` configuration option.
-
-Possible values:
-    * True
-    * False
-
-Related options:
-    * image_property_quota
-
-""")),
     cfg.StrOpt('hashing_algorithm',
                default='sha512',
                help=_("""
@@ -255,12 +225,6 @@ Maximum number of properties allowed on an image.
 This enforces an upper limit on the number of additional properties an image
 can have. Any negative value is interpreted as unlimited.
 
-NOTE: This won't have any impact if additional properties are disabled. Please
-refer to ``allow_additional_image_properties``.
-
-Related options:
-    * ``allow_additional_image_properties``
-
 """)),
     cfg.IntOpt('image_tag_quota', default=128,
                help=_("""
@@ -340,8 +304,8 @@ location is where the image data is stored in backend storage. This
 image location is shown under the image property ``direct_url``.
 
 When multiple image locations exist for an image, the best location
-is displayed based on the location strategy indicated by the
-configuration option ``location_strategy``.
+is displayed based on the store weightage assigned for each store
+indicated by the configuration option ``weight``.
 
 NOTES:
     * Revealing image locations can present a GRAVE SECURITY RISK as
@@ -358,7 +322,7 @@ Possible values:
 
 Related options:
     * show_multiple_locations
-    * location_strategy
+    * weight
 
 """)),
     # NOTE(flaper87): The policy.yaml file should be updated and the location
@@ -390,9 +354,9 @@ Show all image locations when returning an image.
 This configuration option indicates whether to show all the image
 locations when returning image details to the user. When multiple
 image locations exist for an image, the locations are ordered based
-on the location strategy indicated by the configuration opt
-``location_strategy``. The image locations are shown under the
-image property ``locations``.
+on the store weightage assigned for each store indicated by the
+configuration option ``weight``. The image locations are shown
+under the image property ``locations``.
 
 NOTES:
     * Revealing image locations can present a GRAVE SECURITY RISK as
@@ -411,8 +375,24 @@ Possible values:
 
 Related options:
     * show_image_direct_url
-    * location_strategy
+    * weight
 
+""")),
+    cfg.BoolOpt('do_secure_hash', default=True,
+                help=_("""
+Calculate hash and checksum for the image.
+
+This configuration option indicates that /v2/images/{image_id}/locations
+POST API will calculate hash and checksum of the image on the fly.
+If False it will silently ignore the hash and checksum calculation.
+
+Possible values:
+    * True
+    * False
+""")),
+    cfg.IntOpt('http_retries', default=3,
+               help=_("""
+The number of times to retry when any operation fails.
 """)),
     cfg.IntOpt('image_size_cap', default=1099511627776, min=1,
                max=9223372036854775808,
@@ -511,6 +491,16 @@ Related options:
 
 """)),
     cfg.StrOpt('metadata_encryption_key',
+               deprecated_for_removal=True,
+               deprecated_since="Dalmatian",
+               deprecated_reason=_("""
+This option doesnt serves the purpose of encryption of location metadata,
+whereas it encrypts location url only for specific APIs. Also if enabled
+this during an upgrade may disrupt existing deployments, as it does not
+support/provide db upgrade script to encrypt existing location URLs.
+Moreover, its functionality for encrypting location URLs is inconsistent
+which is resulting in download failures.
+"""),
                secret=True,
                help=_("""
 AES key for encrypting store location metadata.
@@ -530,6 +520,11 @@ Related options:
 """)),
     cfg.StrOpt('digest_algorithm',
                default='sha256',
+               deprecated_for_removal=True,
+               deprecated_since="Dalmatian",
+               deprecated_reason=_("""
+This option has had no effect since the removal of native SSL support.
+"""),
                help=_("""
 Digest algorithm to use for digital signature.
 
@@ -593,30 +588,6 @@ Related options:
 
     Related options:
         * [DEFAULT]/node_staging_uri""")),
-    cfg.BoolOpt('enforce_secure_rbac', default=False,
-                deprecated_for_removal=True,
-                deprecated_reason=_("""
-This option has been introduced to require operators to opt into enforcing
-authorization based on common RBAC personas, which is EXPERIMENTAL as of the
-Wallaby release. This behavior will be the default and STABLE in a future
-release, allowing this option to be removed.
-"""),
-                deprecated_since='Wallaby',
-                help=_("""
-Enforce API access based on common persona definitions used across OpenStack.
-Enabling this option formalizes project-specific read/write operations, like
-creating private images or updating the status of shared image, behind the
-`member` role. It also formalizes a read-only variant useful for
-project-specific API operations, like listing private images in a project,
-behind the `reader` role.
-
-Operators should take an opportunity to understand glance's new image policies,
-audit assignments in their deployment, and update permissions using the default
-roles in keystone (e.g., `admin`, `member`, and `reader`).
-
-Related options:
-    * [oslo_policy]/enforce_new_defaults
-""")),
     cfg.StrOpt('worker_self_reference_url',
                default=None,
                help=_("""
@@ -681,7 +652,12 @@ def parse_args(args=None, usage=None, default_config_files=None):
 
 
 def parse_cache_args(args=None):
-    config_files = cfg.find_config_files(project='glance', prog='glance-cache')
+    config_files = cfg.find_config_files(project='glance', prog='glance-api')
+    # NOTE(abhishekk): Reading glance-api file first and glance-cache file
+    # later so that if glance-cache file has different values set for some
+    # cache related options then they should take precedence.
+    config_files.extend(cfg.find_config_files(project='glance',
+                                              prog='glance-cache'))
     parse_args(args=args, default_config_files=config_files)
 
 
