@@ -56,6 +56,7 @@ import glance.db
 from glance import housekeeping
 from glance import i18n
 from glance.i18n import _, _LE, _LI, _LW
+from glance import sqlite_migration
 
 
 bind_opts = [
@@ -454,8 +455,21 @@ class BaseServer(metaclass=abc.ABCMeta):
         self.application = application
         self.default_port = default_port
         self.configure()
+
+        # NOTE(abhishekk): This will raise RuntimeError if
+        # worker_self_reference_url is not set in glance-api.conf
+        sqlite_migration.migrate_if_required()
         self.start_wsgi()
 
+        # NOTE(danms): This may raise GlanceException if the staging store is
+        # not configured properly, which will be caught and printed by
+        # cmd/api.py as an error message and abort startup.
+        staging = housekeeping.staging_store_path()
+        if not os.path.exists(staging) and CONF.enabled_import_methods:
+            LOG.warning(_LW('Import methods are enabled but staging directory '
+                            '%(path)s does not exist; Imports will fail!'),
+                        {'path': staging})
+
         cleaner = housekeeping.StagingStoreCleaner(glance.db.get_api())
         self.pool.spawn_n(cleaner.clean_orphaned_staging_residue)
 
@@ -482,7 +496,7 @@ class BaseServer(metaclass=abc.ABCMeta):
         Apply configuration settings
 
         :param old_conf: Cached old configuration settings (if any)
-        :param has changed: callable to determine if a parameter has changed
+        :param has_changed: callable to determine if a parameter has changed
         """
         eventlet.wsgi.MAX_HEADER_LINE = CONF.max_header_line
         self.client_socket_timeout = CONF.client_socket_timeout or None
@@ -765,6 +779,8 @@ class Win32Server(BaseServer):
     _sock = None
 
     def __init__(self, *args, **kwargs):
+        LOG.warning("Support for Glance on Windows operating systems is"
+                    "deprecated.")
         super(Win32Server, self).__init__(*args, **kwargs)
         self._launcher = Win32ProcessLauncher()
         self._ioutils = os_win_utilsfactory.get_ioutils()
